# Architecture documents

This section contains architecture-related documents for the *Kiara* project.

Not all of those might be up-to-date, but they should help to understand certain design decisions, and why they were made.
